Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(592)

Unified Diff: chrome/browser/ui/webui/signin/login_ui_service.h

Issue 1868273002: Enhanced Sync Confirmation modal (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed Dan's comments + rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/signin/login_ui_service.h
diff --git a/chrome/browser/ui/webui/signin/login_ui_service.h b/chrome/browser/ui/webui/signin/login_ui_service.h
index ce3ffead914a26b9fa92f857195ef44f7c4c5216..bc789a38b47482210f7e8565525ba68220a4e9f2 100644
--- a/chrome/browser/ui/webui/signin/login_ui_service.h
+++ b/chrome/browser/ui/webui/signin/login_ui_service.h
@@ -33,7 +33,7 @@ class LoginUIService : public KeyedService {
// Used when the sync confirmation UI is closed to signify which option was
// selected by the user.
- enum SyncConfirmationUIClosedResults {
+ enum SyncConfirmationUIClosedResult {
// Start sync immediately.
SYNC_WITH_DEFAULT_SETTINGS,
// Show the user the sync settings before starting sync.
@@ -53,10 +53,10 @@ class LoginUIService : public KeyedService {
// |ui| The login UI that was just closed; will never be null.
virtual void OnLoginUIClosed(LoginUI* ui) {}
// Called when the sync confirmation UI is closed. |results| indicates the
// option chosen by the user in the confirmation UI.
virtual void OnSyncConfirmationUIClosed(
- SyncConfirmationUIClosedResults results) {}
+ SyncConfirmationUIClosedResult result) {}
// Called when a confirmation UI for untrusted signin is shown.
virtual void OnUntrustedLoginUIShown() {}
@@ -85,8 +85,9 @@ class LoginUIService : public KeyedService {
// sets current_login_ui() to null.
void LoginUIClosed(LoginUI* ui);
- // Called when the sync settings confirmation UI is closed.
- void SyncConfirmationUIClosed(SyncConfirmationUIClosedResults results);
+ // Called when the sync confirmation UI is closed. |result| indicates the
+ // option chosen by the user in the confirmation UI.
+ void SyncConfirmationUIClosed(SyncConfirmationUIClosedResult result);
// Called when a confirmation UI for untrusted signin is shown.
void UntrustedLoginUIShown();
« no previous file with comments | « chrome/browser/ui/webui/options/sync_setup_handler.cc ('k') | chrome/browser/ui/webui/signin/login_ui_service.cc » ('j') | no next file with comments »
@@ -53,10 +53,10 @@ class LoginUIService : public KeyedService {
// |ui| The login UI that was just closed; will never be null.
virtual void OnLoginUIClosed(LoginUI* ui) {}
- // Called when the sync confirmation UI is closed. |results| indicates the
+ // Called when the sync confirmation UI is closed. |result| indicates the
// option chosen by the user in the confirmation UI.
virtual void OnSyncConfirmationUIClosed(

Powered by Google App Engine
This is Rietveld 408576698